# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.sse_server_config import SseServerConfig
from ...types.stdio_server_config import StdioServerConfig

ListMcpServersResponseValue = typing.Union[SseServerConfig, StdioServerConfig]
